Module types

Module types 

Core data types for the shift scheduling system.

Structs

ShiftCycleConfig
Runtime shift cycle configuration.
ShiftInfo
Result of querying what shift falls on a given date.

Enums

ShiftType
The five shift types in a standard Chinese rotating shift system.

Functions

predecessor_team_id
The team that yours follows in the circular rotation order.
successor_team_id
The team that follows yours in the circular rotation order.
team_name
Chinese team name for a team ID.