Core data types for the shift scheduling system.
Structs
- Shift
Cycle Config - Runtime shift cycle configuration.
- Shift
Info - Result of querying what shift falls on a given date.
Enums
- Shift
Type - The five shift types in a standard Chinese rotating shift system.
Functions
- predecessor_
team_ id - The team that yours follows in the circular rotation order.
- successor_
team_ id - The team that follows yours in the circular rotation order.
- team_
name - Chinese team name for a team ID.