Core data types for the shift scheduling system.
Structs
- Shift
Cycle Config - Runtime shift cycle configuration.
- Shift
Info - Result of querying what shift falls on a given date.
Enums
- Shift
Type - The five shift types in a standard Chinese rotating shift system.
Functions
- team_
name - Chinese team name for a team ID.